# mypy-boto3-servicediscovery

[![PyPI - mypy-boto3-servicediscovery](https://img.shields.io/pypi/v/mypy-boto3-servicediscovery.svg?color=blue)](https://pypi.org/project/mypy-boto3-servicediscovery)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-servicediscovery.svg?color=blue)](https://pypi.org/project/mypy-boto3-servicediscovery)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-servicediscovery?color=blue)](https://pypistats.org/packages/mypy-boto3-servicediscovery)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.ServiceDiscovery 1.17.61](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/servicediscovery.html#ServiceDiscovery) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.7.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-servicediscovery](#mypy-boto3-servicediscovery)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `ServiceDiscovery` service.

```bash
python -m pip install boto3-stubs[servicediscovery]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[servicediscovery]` in your environment: `python -m pip install 'boto3-stubs[servicediscovery]'`

Both type checking and auto-complete should work for `ServiceDiscovery` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[servicediscovery]` in your environment: `python -m pip install 'boto3-stubs[servicediscovery]'`

Both type checking and auto-complete should work for `ServiceDiscovery` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[servicediscovery]` in your environment: `python -m pip install 'boto3-stubs[servicediscovery]'`
- Run `mypy` as usual

Type checking should work for `ServiceDiscovery` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[servicediscovery]` in your environment: `python -m pip install 'boto3-stubs[servicediscovery]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ServiceDiscovery` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`ServiceDiscoveryClient` provides annotations for `boto3.client("servicediscovery")`.

```python
import boto3

from mypy_boto3_servicediscovery import ServiceDiscoveryClient

client: ServiceDiscoveryClient = boto3.client("servicediscovery")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ServiceDiscoveryClient = session.client("servicediscovery")
```

### Paginators annotations

`mypy_boto3_servicediscovery.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_servicediscovery import ServiceDiscoveryClient
from mypy_boto3_servicediscovery.paginator import (
    ListInstancesPaginator,
    ListNamespacesPaginator,
    ListOperationsPaginator,
    ListServicesPaginator,
)

client: ServiceDiscoveryClient = boto3.client("servicediscovery")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_instances_paginator: ListInstancesPaginator = client.get_paginator("list_instances")
list_namespaces_paginator: ListNamespacesPaginator = client.get_paginator("list_namespaces")
list_operations_paginator: ListOperationsPaginator = client.get_paginator("list_operations")
list_services_paginator: ListServicesPaginator = client.get_paginator("list_services")
```







### Literals

`mypy_boto3_servicediscovery.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_servicediscovery.literals import (
    CustomHealthStatus,
    FilterCondition,
    HealthCheckType,
    HealthStatus,
    HealthStatusFilter,
    ListInstancesPaginatorName,
    ListNamespacesPaginatorName,
    ListOperationsPaginatorName,
    ListServicesPaginatorName,
    NamespaceFilterName,
    NamespaceType,
    OperationFilterName,
    OperationStatus,
    OperationTargetType,
    OperationType,
    RecordType,
    RoutingPolicy,
    ServiceFilterName,
    ServiceType,
    ServiceTypeOption,
)

def check_value(value: CustomHealthStatus) -> bool:
    ...
```



### Typed dictionaries

`mypy_boto3_servicediscovery.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_servicediscovery.type_defs import (
    DnsConfigChangeTypeDef,
    DnsConfigTypeDef,
    DnsPropertiesTypeDef,
    DnsRecordTypeDef,
    HealthCheckConfigTypeDef,
    HealthCheckCustomConfigTypeDef,
    HttpInstanceSummaryTypeDef,
    HttpPropertiesTypeDef,
    InstanceSummaryTypeDef,
    InstanceTypeDef,
    NamespacePropertiesTypeDef,
    NamespaceSummaryTypeDef,
    NamespaceTypeDef,
    OperationSummaryTypeDef,
    OperationTypeDef,
    ServiceSummaryTypeDef,
    ServiceTypeDef,
    TagTypeDef,
    CreateHttpNamespaceResponseTypeDef,
    CreatePrivateDnsNamespaceResponseTypeDef,
    CreatePublicDnsNamespaceResponseTypeDef,
    CreateServiceResponseTypeDef,
    DeleteNamespaceResponseTypeDef,
    DeregisterInstanceResponseTypeDef,
    DiscoverInstancesResponseTypeDef,
    GetInstanceResponseTypeDef,
    GetInstancesHealthStatusResponseTypeDef,
    GetNamespaceResponseTypeDef,
    GetOperationResponseTypeDef,
    GetServiceResponseTypeDef,
    ListInstancesResponseTypeDef,
    ListNamespacesResponseTypeDef,
    ListOperationsResponseTypeDef,
    ListServicesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    NamespaceFilterTypeDef,
    OperationFilterTypeDef,
    PaginatorConfigTypeDef,
    RegisterInstanceResponseTypeDef,
    ServiceChangeTypeDef,
    ServiceFilterTypeDef,
    UpdateServiceResponseTypeDef,
)

def get_structure() -> DnsConfigChangeTypeDef:
    return {
      ...
    }
```
